#
# spec file for package agenda
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.github.dahenson.agenda
Name:           agenda
Version:        1.1.2
Release:        2.4
Summary:        Task Manager for Elementary
License:        GPL-3.0-or-later
URL:            https://github.com/dahenson/agenda
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.40.
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(granite) >= 5.3.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.16
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(vapigen) >= 0.26.0
Provides:       agenda-tasks = %{version}
Obsoletes:      agenda-tasks < %{version}

%description
A task manager for the Pantheon Desktop.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%{_datadir}/metainfo/%{appid}.appdata.xml
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,48x48@2,48x48@2/apps,64x64@2,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Sun Nov 17 2024 Richard Rahl <rrahl0@opensuse.org>
- update spec file for Leap 16.0:
  * remove %%suse_update_desktop_file
  * remove HiDPI workaround
  * use autosetup
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.2:
  * Bug Fixes
  * Fixed the issue where the task list is not saved on
    unexpected quit
  * Fixed the issue where the window position and size are not
    saved on unexpected quit
  * Added Ctrl-Q and Ctrl-W keyboard shortcuts for closing the
    window
  * Packaged the app as a flatpak for elementary OS 6!
  * Fixed some theme issues
* Wed Mar 11 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * Merge pull request #115 from dahenson/develop
  * Merge pull request #114 from dahenson/prepare-for-release
  * Set node version to 10.17.0 for travis
  * Update copyright year on appdata
  * Update appdata with new version info
  * Bump version number
  * Update copyright years
  * Merge pull request #113 from dahenson/run-vala-lint
  * Update src/Window.vala
  * Fix formatting issues in the code
  * Merge pull request #110 from dahenson/fix-click-to-deselect
  * Merge pull request #111 from ryonakano/l10n-update
  * Add css fixes to hide focused checks
  * Update POTFILES
  * Merge pull request #109 from dahenson/css-fixes
  * Listen for button press event
  * Small updates to fix the treeview entry
  * Only use the stylesheet if it runs on elementary
  * Merge pull request #106 from ryonakano/improve-meson
  * Use 4 spaces instead of a tab
  * Merge branch 'develop' into improve-meson
  * Address suggested changes
  * Merge branch 'master' into develop
  * Merge pull request #107 from
    ryonakano/give-first-time-value-meaning
  * Fix the GSettings value 'first-time' has no meaning
  * README: Update installation instructions to Meson
  * Remove stale INSTALL
  * Remove no longer used pot
  * Unify the number of indentation to 4
  * Remove unnecessary constants
  * Merge pull request #103 from meisenzahl/master
  * Downgrade Node.js to fix builds on Travis CI
  * Remove cache from travis.yml
  * Merge pull request #99 from dahenson/undo-feature
  * Add ability to undo reordering to TaskList
  * ...
- Drop fix-build.patch
- Switch to meson
- Spec file cleanup
* Mon Apr  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add fix-build.patch. With recent vala versions, --thread is
  ignored but that also causes a build issue on openSUSE Factory.
* Mon Sep 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.12:
  * Update com.github.dahenson.agenda.appdata.xml
  * Merge pull request #79 from ryonakano/fix-icon-url
* Sat Aug 18 2018 avvissu@yandex.by
- Update to 1.0.11:
  * Bump version
  * Get rid of those pesky whole screen screenshots.
* Tue Aug 14 2018 avvissu@yandex.by
- Update to 1.0.10:
  * Bump version number
  * Change some wording to be more clear and concise.
  * Change some wording and add release info
  * Add additional screenshots
  * Add the right prefix flag to cmake
  * Add more screenshots
  * Fix table in README again?
  * Fix table in README
  * Fix screenshot and add a new one.
  * Rearrange some stuff
  * Add special thanks
  * Fix some wording and fix the icon
  * Improve README
  * Fix id field
  * Add OARS data to AppData
  * Remove cache section of Travis config
  * Remove packaging, moved to orphan branch
  * Add suggested price
  * Add the GResource.cmake dependency
  * Add travis CI integration
  * Update the stylesheet for Juno
  * Add GResource to cmake to fix build
  * Remove backend file. Not needed yet.
  * Fix licensing and some whitespace
- Remove obsolete macros
- Change the home page
- Add LICENSE file
* Tue Dec 19 2017 jengelh@inai.de
- Trim biased wording from description.
* Tue Nov 28 2017 avvissu@yandex.by
- Update to 1.0.9:
  * Fix appdata and add LICENSE
  * Bump version, update changelog
- Drop agenda-1.0.8-vala-0.36.patch (fixed)
* Tue Nov  7 2017 avvissu@yandex.by
- Update to 1.0.8:
  * Changed styling for "dark theme variant"
  * Changed styles for editing a task in the list
  * Added hype to the AppData.xml Description to try to stand out in
    AppCenter better
  * Removed the About dialog completely
  * Fixes issue where the correct GLib Settings schema is installed,
    but the app expects the old schema
  * RDNN fixes for debian packaging
  * Style changes and metadata
  * Fixes TaskEntry selection bug
  * Better styling for the TreeView
- Switch from bzr to git
- Rename the package: agenda-tasks -> agenda
- agenda-tasks-0.3.1-vala-0.36.patch > agenda-1.0.8-vala-0.36.patch
* Tue May  2 2017 avvissu@yandex.by
- Fix build with vala >= 0.36 (agenda-tasks-0.3.1-vala-0.36.patch)
* Thu Apr 21 2016 mailaender@opensuse.org
- initial packaging (version 0.3.1+r108)
